@@ -2,6 +2,7 @@
 
 COMPILE_FROM_SOURCE=0
 FORCE_ROOT=0
+OVERRIDE_OS=0
 
 function usage() {
 	echo "Powershell Empire installer"
@@ -9,14 +10,17 @@ function usage() {
 	echo "OPTIONS:"
 	echo "  -y    Assume Yes to all questions (install all optional dependencies)"
 	echo "  -f    Force install as root (not recommended)"
+	echo "  -c    Compile Empire-Compiler from source"
+	echo "  -o    Override OS check"
 	echo "  -h    Displays this help text"
 }
 
-while getopts "hcyf" option; do
+while getopts "hcyfo" option; do
 	case "${option}" in
 	c) COMPILE_FROM_SOURCE=1 ;;
 	y) ASSUME_YES=1 ;;
 	f) FORCE_ROOT=1 ;;
+	o) OVERRIDE_OS=1 ;;
 	h)
 		usage
 		exit
@@ -239,7 +243,7 @@ sudo -v
 PARENT_PATH=$( cd "$(dirname "${BASH_SOURCE[0]}")" ; cd .. ; pwd -P )
 OS_NAME=
 VERSION_ID=
-if VERSION_ID=$(grep -oP '^(11|12)' /etc/debian_version 2>/dev/null); then
+if VERSION_ID=$(grep -oP '^(11|12|13)' /etc/debian_version 2>/dev/null); then
   echo -e "\x1b[1;34m[*] Detected Debian $VERSION_ID\x1b[0m"
   OS_NAME="DEBIAN"
 elif grep -i "NAME=\"Ubuntu\"" /etc/os-release 2>/dev/null; then
@@ -247,6 +251,8 @@ elif grep -i "NAME=\"Ubuntu\"" /etc/os-release 2>/dev/null; then
   VERSION_ID=$(grep -i VERSION_ID /etc/os-release | grep -o -E "[[:digit:]]+\\.[[:digit:]]+")
   if [[ "$VERSION_ID" == "20.04" || "$VERSION_ID" == "22.04" || "$VERSION_ID" == "24.04" ]]; then
     echo -e "\x1b[1;34m[*] Detected Ubuntu ${VERSION_ID}\x1b[0m"
+  elif [ "$OVERRIDE_OS" -eq 1 ]; then
+    echo -e "\x1b[1;33m[!] Warning: Overriding Ubuntu version check ($VERSION_ID). This may lead to unexpected behavior.\x1b[0m"
   else
     echo -e '\x1b[1;31m[!] Ubuntu must be 20.04, 22.04, or 24.04 \x1b[0m' && exit
   fi
@@ -258,7 +264,13 @@ elif grep -i "Parrot" /etc/os-release 2>/dev/null; then
   OS_NAME=PARROT
   VERSION_ID=$(grep -i VERSION_ID /etc/os-release | grep -o -E [[:digit:]]+\\.[[:digit:]]+)
 else
-  echo -e '\x1b[1;31m[!] Unsupported OS. Exiting.\x1b[0m' && exit
+  if [ "$OVERRIDE_OS" -eq 1 ]; then
+    echo -e "\x1b[1;33m[!] Warning: Overriding OS check. This may lead to unexpected behavior.\x1b[0m"
+    OS_NAME="UNKNOWN"
+    VERSION_ID="UNKNOWN"
+  else
+    echo -e '\x1b[1;31m[!] Unsupported OS. Exiting.\x1b[0m' && exit
+  fi
 fi
 
 sudo apt-get update
