@@ -217,6 +217,7 @@ class Listener(Base):
     listener_type = Column(String(255), nullable=True)
     listener_category = Column(String(255), nullable=False)
     enabled = Column(Boolean, nullable=False)
+    host_address = Column(String(255), nullable=True)
     options = Column(JSON)
     created_at = Column(UtcDateTime, nullable=False, default=utcnow())
     tags = relationship("Tag", secondary=listener_tag_assc)
@@ -469,6 +470,7 @@ class AgentTask(Base):
         UtcDateTime, default=utcnow(), onupdate=utcnow(), nullable=False
     )
     module_name = Column(Text)
+    module_options = Column(JSON)
     task_name = Column(Text)
     status = Column(Enum(AgentTaskStatus), index=True)
     downloads = relationship("Download", secondary=agent_task_download_assc)
@@ -520,6 +522,7 @@ class PluginTask(Base):
     updated_at = Column(
         UtcDateTime, default=utcnow(), onupdate=utcnow(), nullable=False
     )
+    plugin_options = Column(JSON)
     task_name = Column(Text)
     status = Column(Enum(PluginTaskStatus), index=True)
     downloads = relationship("Download", secondary=plugin_task_download_assc)
@@ -581,6 +584,7 @@ class Bypass(Base):
     authors = Column(JSON)
     code = Column(Text)
     language = Column(String(255))
+    is_default = Column(Boolean, default=False, nullable=False)
     created_at = Column(UtcDateTime, nullable=False, default=utcnow())
     updated_at = Column(
         UtcDateTime, default=utcnow(), onupdate=utcnow(), nullable=False
