@@ -1,11 +1,38 @@
+import copy
 from pathlib import Path
 
 import pytest
+import yaml
 
+from empire.server.core.config import config_manager
 from empire.server.core.config.config_manager import EmpireConfig
 from empire.server.core.db.defaults import get_staging_key
 from empire.test.conftest import load_test_config
 
+BASE_CONFIG = {
+    "api": {"port": 1337, "ip": "0.0.0.0"},
+    "database": {
+        "use": "sqlite",
+        "sqlite": {"location": "empire.db"},
+        "mysql": {
+            "url": "localhost:3306",
+            "username": "",
+            "password": "",
+            "database_name": "empire",
+        },
+        "defaults": {
+            "staging_key": "",
+            "username": "empireadmin",
+            "password": "password123",
+            "obfuscation": [],
+            "keyword_obfuscation": [],
+            "bypasses": [],
+            "ip_allow_list": [],
+            "ip_deny_list": [],
+        },
+    },
+}
+
 
 def test_config_resolves_path():
     server_config_dict = load_test_config()
@@ -134,3 +161,67 @@ def test_config_accepts_unknown_default_bypass_name():
 
     assert "fake_bypass" in cfg.database.defaults.bypasses
     assert set(cfg.database.defaults.bypasses) >= {"mattifestation", "etw"}
+
+
+@pytest.fixture(autouse=False)
+def _isolated_config(monkeypatch):
+    """Isolate tests that use _base_config_path from env vars and global state."""
+    original = config_manager._module_base_config_path
+    # Clear env vars that would override YAML sources in the test
+    monkeypatch.delenv("EMPIRE_DATABASE__USE", raising=False)
+    monkeypatch.delenv("DATABASE_USE", raising=False)
+    yield
+    config_manager._module_base_config_path = original
+
+
+@pytest.mark.usefixtures("_isolated_config")
+def test_user_config_layers_on_base(tmp_path):
+    """User config overrides specific values while base values fall through."""
+    base = tmp_path / "config.yaml"
+    base.write_text(yaml.dump(BASE_CONFIG))
+
+    user = tmp_path / "config.user.yaml"
+    user.write_text(yaml.dump({"api": {"port": 8443}}))
+
+    config = EmpireConfig(_base_config_path=base)
+
+    assert config.api.port == 8443  # noqa: PLR2004
+    assert config.api.ip == "0.0.0.0"
+    assert config.database.use == "sqlite"
+
+
+@pytest.mark.usefixtures("_isolated_config")
+def test_no_user_config_uses_base_only(tmp_path):
+    """When no config.user.yaml exists, base config is used as-is."""
+    base = tmp_path / "config.yaml"
+    base.write_text(yaml.dump(BASE_CONFIG))
+
+    config = EmpireConfig(_base_config_path=base)
+
+    assert config.api.port == 1337  # noqa: PLR2004
+    assert config.api.ip == "0.0.0.0"
+    assert config.database.use == "sqlite"
+
+
+@pytest.mark.usefixtures("_isolated_config")
+def test_user_config_deep_merges_nested_dicts(tmp_path):
+    """User config overrides nested fields without clobbering siblings."""
+    base_config = copy.deepcopy(BASE_CONFIG)
+    base_config["database"]["mysql"]["username"] = "default_user"
+    base_config["database"]["mysql"]["password"] = "default_pass"
+
+    base = tmp_path / "config.yaml"
+    base.write_text(yaml.dump(base_config))
+
+    user = tmp_path / "config.user.yaml"
+    user.write_text(
+        yaml.dump({"database": {"use": "mysql", "mysql": {"password": "secret"}}})
+    )
+
+    config = EmpireConfig(_base_config_path=base)
+
+    assert config.database.use == "mysql"
+    assert config.database.mysql.password == "secret"
+    assert config.database.mysql.username == "default_user"
+    assert config.database.mysql.url == "localhost:3306"
+    assert config.api.port == 1337  # noqa: PLR2004
